pub struct RecordingOptions {
pub audio: Option<bool>,
pub transcription: Option<bool>,
pub video: Option<bool>,
}Expand description
recording modes requested by a user
missing fields mean the caller did not request that mode
the room combines these options with feature flags, current recording state
and UserPermissions before mutating recording state
Fields
audio: Option<bool>transcription: Option<bool>video: Option<bool>Trait Implementations
Sourceimpl Clone for RecordingOptions
impl Clone for RecordingOptions
Sourcefn clone(&self) -> RecordingOptions
fn clone(&self) -> RecordingOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RecordingOptions
impl Debug for RecordingOptions
Sourceimpl Default for RecordingOptions
impl Default for RecordingOptions
Sourcefn default() -> RecordingOptions
fn default() -> RecordingOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RecordingOptions
impl<'de> Deserialize<'de> for RecordingOptions
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<RecordingOptions, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<RecordingOptions, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for RecordingOptions
impl PartialEq for RecordingOptions
Sourceimpl Serialize for RecordingOptions
impl Serialize for RecordingOptions
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for RecordingOptions
impl StructuralPartialEq for RecordingOptions